@@ -1,13 +1,17 @@
 package Log::Any::IfLOG;
 
-our $DATE = '2015-04-05'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 my $log_singleton;
 
 our $DEBUG;
 our $ENABLE_LOG;
 
+sub __init_log_singleton {
+    if (!$log_singleton) { $log_singleton = Object::Dumb->new }
+}
+
 sub import {
     my $self = shift;
 
@@ -31,12 +35,17 @@ sub import {
     } else {
         my $saw_log_param = grep { $_ eq '$log' } @_;
         if ($saw_log_param) {
-            if (!$log_singleton) { $log_singleton = Object::Dumb->new }
+            __init_log_singleton();
             *{"$caller\::log"} = \$log_singleton;
         }
     }
 }
 
+sub get_logger {
+    __init_log_singleton();
+    $log_singleton;
+}
+
 package
     Object::Dumb;
 sub new { my $o = ""; bless \$o, shift }
@@ -57,7 +66,7 @@ Log::Any::IfLOG - Load Log::Any only if "logging is enabled"
 
 =head1 VERSION
 
-This document describes version 0.05 of Log::Any::IfLOG (from Perl distribution Log-Any-IfLOG), released on 2015-04-05.
+This document describes version 0.06 of Log::Any::IfLOG (from Perl distribution Log-Any-IfLOG), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
